package com.zehong.system.service.impl;

import java.util.List;
import com.zehong.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.TYehuaqiDeviceMapper;
import com.zehong.system.domain.TYehuaqiDevice;
import com.zehong.system.service.ITYehuaqiDeviceService;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author zehong
 * @date 2022-09-14
 */
@Service
public class TYehuaqiDeviceServiceImpl implements ITYehuaqiDeviceService 
{
    @Autowired
    private TYehuaqiDeviceMapper tYehuaqiDeviceMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param detectorId 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    @Override
    public TYehuaqiDevice selectTYehuaqiDeviceById(Long detectorId)
    {
        return tYehuaqiDeviceMapper.selectTYehuaqiDeviceById(detectorId);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tYehuaqiDevice 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<TYehuaqiDevice> selectTYehuaqiDeviceList(TYehuaqiDevice tYehuaqiDevice)
    {
        return tYehuaqiDeviceMapper.selectTYehuaqiDeviceList(tYehuaqiDevice);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param tYehuaqiDevice 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertTYehuaqiDevice(TYehuaqiDevice tYehuaqiDevice)
    {
        tYehuaqiDevice.setCreateTime(DateUtils.getNowDate());
        return tYehuaqiDeviceMapper.insertTYehuaqiDevice(tYehuaqiDevice);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param tYehuaqiDevice 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateTYehuaqiDevice(TYehuaqiDevice tYehuaqiDevice)
    {
        tYehuaqiDevice.setUpdateTime(DateUtils.getNowDate());
        return tYehuaqiDeviceMapper.updateTYehuaqiDevice(tYehuaqiDevice);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param detectorIds 需要删除的【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteTYehuaqiDeviceByIds(Long[] detectorIds)
    {
        return tYehuaqiDeviceMapper.deleteTYehuaqiDeviceByIds(detectorIds);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param detectorId 【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteTYehuaqiDeviceById(Long detectorId)
    {
        return tYehuaqiDeviceMapper.deleteTYehuaqiDeviceById(detectorId);
    }
}
